summaryrefslogtreecommitdiffstats
path: root/kdeui/kaboutkde.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdeui/kaboutkde.h')
-rw-r--r--kdeui/kaboutkde.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kdeui/kaboutkde.h b/kdeui/kaboutkde.h
index 357dc339a..07e325dd8 100644
--- a/kdeui/kaboutkde.h
+++ b/kdeui/kaboutkde.h
@@ -50,10 +50,10 @@ class KDEUI_EXPORT KAboutKDE : public KAboutDialog
* @param name Internal name of the widget. This name in not used in the
* caption.
* @param modal If false, this widget will be modeless and must be
* made visible using QWidget::show(). Otherwise it will be
* modal and must be made visible using QWidget::exec()
*/
- KAboutKDE( QWidget *parent=0, const char *name=0, bool modal=true );
+ KAboutKDE( TQWidget *parent=0, const char *name=0, bool modal=true );
};
@@ -50,10 +50,10 @@ class KDEUI_EXPORT KAboutKDE : public KAboutDialog
* caption.
* @param modal If false, this widget will be modeless and must be
- * made visible using QWidget::show(). Otherwise it will be
- * modal and must be made visible using QWidget::exec()
+ * made visible using TQWidget::show(). Otherwise it will be
+ * modal and must be made visible using TQWidget::exec()
*/